@@ -11,7 +11,7 @@ import shutil
 class CentralReachCore(SitesCore):
     def __init__(self, login: str, password: str, url: str = 'https://members.centralreach.com/#login',
                  start_date: date = date.today().replace(day=1), end_date: date = date.today(),
-                 timeout: int = 30, temp_folder: str = ''):
+                 timeout: int = 30, temp_folder: str = '', headless: bool = False):
         """
         CentralReachCore object. Please Inheritance it.
 
@@ -23,7 +23,7 @@ class CentralReachCore(SitesCore):
         :param timeout: timeout for action. The default value is 30 seconds.
         :param temp_folder: Path to temp folder. The default value is temp/cr.
         """
-        super().__init__(login, password, url, timeout, temp_folder)
+        super().__init__(login, password, url, timeout, temp_folder, headless)
         self.start_date: date = start_date
         self.end_date: date = end_date
 
@@ -44,7 +44,7 @@ class CentralReachCore(SitesCore):
 
         for i in range(1, 4):
             try:
-                self.browser.open_chrome_browser(self.url)
+                self.browser.open_chrome_browser(self.url, headless=self._headless)
                 self.browser.set_window_size(1920, 1080)
                 self.browser.maximize_browser_window()
 
