@@ -5,7 +5,8 @@ from time import sleep
 from datetime import datetime, timedelta
 from ..basic.core import SitesCore
 from .grouped_row import GroupedRow
-import SeleniumLibrary.errors
+from SeleniumLibrary.errors import SeleniumLibraryException
+from selenium.common.exceptions import StaleElementReferenceException
 
 
 class QuickbooksCore(SitesCore):
@@ -108,7 +109,7 @@ class QuickbooksCore(SitesCore):
             if self.browser.does_page_contain_element(xpath):
                 try:
                     is_success = self.browser.find_element(xpath).is_displayed()
-                except SeleniumLibrary.errors.ElementNotFound:
+                except SeleniumLibraryException:
                     sleep(1)
 
         if not is_success and is_need_screenshot:
@@ -131,7 +132,7 @@ class QuickbooksCore(SitesCore):
                         )
                         element.click()
                         self.browser.wait_until_element_is_not_visible(f'({xpath})[{elements.index(element) + 1}]')
-                except (AssertionError, SeleniumLibrary.errors.ElementNotFound):
+                except (AssertionError, SeleniumLibraryException, StaleElementReferenceException):
                     sleep(1)
 
     def go_to_client_page(self, client_name: str) -> None:
